from haystack import indexes

from councilmatic_core.models import Bill
from councilmatic_core.templatetags.extras import clean_html


class BillIndex(indexes.SearchIndex):

    text = indexes.CharField(
        document=True,
        use_template=True,
        template_name="search/indexes/councilmatic_core/bill_text.txt",
    )
    slug = indexes.CharField(model_attr="slug", indexed=False)
    id = indexes.CharField(model_attr="id", indexed=False)
    bill_type = indexes.CharField(faceted=True)
    identifier = indexes.CharField(model_attr="identifier")
    description = indexes.CharField(model_attr="title", boost=1.25)
    source_url = indexes.CharField(model_attr="sources__url", indexed=False)
    source_note = indexes.CharField(model_attr="sources__note")
    abstract = indexes.CharField(
        model_attr="abstracts__abstract", boost=1.25, default=""
    )

    friendly_name = indexes.CharField()
    sort_name = indexes.CharField()
    sponsorships = indexes.MultiValueField(faceted=True)
    actions = indexes.MultiValueField()
    controlling_body = indexes.MultiValueField(faceted=True)
    full_text = indexes.CharField(model_attr="full_text", default="")
    ocr_full_text = indexes.CharField(model_attr="ocr_full_text", default="")
    last_action_date = indexes.DateTimeField()
    inferred_status = indexes.CharField(faceted=True)
    legislative_session = indexes.CharField(faceted=True)

    def get_model(self):
        return Bill

    def prepare_friendly_name(self, obj):
        return obj.friendly_name

    def prepare_sort_name(self, obj):
        return obj.friendly_name.replace(" ", "")

    def prepare_bill_type(self, obj):
        return obj.bill_type.lower()

    def prepare_sponsorships(self, obj):
        return [sponsorship.person for sponsorship in obj.sponsorships.all()]

    def prepare_actions(self, obj):
        return [action for action in obj.actions.all()]

    def prepare_controlling_body(self, obj):
        if obj.controlling_body:
            return [org.name for org in obj.controlling_body]

    def prepare_full_text(self, obj):
        return clean_html(obj.full_text)

    def prepare_inferred_status(self, obj):
        return obj.inferred_status

    def prepare_legislative_session(self, obj):
        return obj.legislative_session.identifier

    def prepare_ocr_full_text(self, obj):
        return clean_html(obj.ocr_full_text)

    def get_updated_field(self):
        return "updated_at"

    def prepare_last_action_date(self, obj):
        if obj.last_action_date:
            return obj.last_action_date



# Generated by Django 2.1.9 on 2019-06-26 21:17

import django.contrib.gis.db.models.fields
import django.core.files.storage
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0004_auto_20171005_2028"),
        ("councilmatic_core", "0047_update_filepath"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Post",
        ),
        migrations.CreateModel(
            name="Post",
            fields=[
                (
                    "post",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="councilmatic_post",
                        serialize=False,
                        to="core.Post",
                    ),
                ),
                (
                    "shape",
                    django.contrib.gis.db.models.fields.GeometryField(
                        null=True, srid=4326
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("core.post",),
        ),
    ]



# Generated by Django 2.1.14 on 2019-11-14 19:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0048_post_shape"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="membership",
            options={"base_manager_name": "objects"},
        ),
        migrations.AlterField(
            model_name="bill",
            name="slug",
            field=models.SlugField(unique=True),
        ),
        migrations.AlterField(
            model_name="event",
            name="slug",
            field=models.SlugField(max_length=200, unique=True),
        ),
        migrations.AlterField(
            model_name="organization",
            name="slug",
            field=models.SlugField(max_length=200, unique=True),
        ),
        migrations.AlterField(
            model_name="person",
            name="slug",
            field=models.SlugField(unique=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-10-13 16:40
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0015_auto_20161012_1626"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="legislativesession",
            name="id",
        ),
        migrations.AlterField(
            model_name="legislativesession",
            name="identifier",
            field=models.CharField(max_length=255, primary_key=True, serialize=False),
        ),
    ]



from django.db.models.signals import post_save
from django.dispatch import receiver
from django.utils.text import slugify, Truncator

from opencivicdata.core.models import (
    Organization as OCDOrganization,
    Person as OCDPerson,
    Post as OCDPost,
)
from opencivicdata.legislative.models import (
    Event as OCDEvent,
    Bill as OCDBill,
    EventRelatedEntity as OCDEventRelatedEntity,
)

from councilmatic_core.models import (
    Organization as CouncilmaticOrganization,
    Person as CouncilmaticPerson,
    Event as CouncilmaticEvent,
    Bill as CouncilmaticBill,
    Post as CouncilmaticPost,
)


@receiver(post_save, sender=OCDOrganization)
def create_councilmatic_org(sender, instance, created, **kwargs):
    if created:
        ocd_part = instance.id.rsplit("-", 1)[-1]
        slug = "{0}-{1}".format(slugify(instance.name), ocd_part)

        co = CouncilmaticOrganization(organization=instance, slug=slug)
        # just update the child table, not the parent table
        co.save_base(raw=True)


@receiver(post_save, sender=OCDPerson)
def create_councilmatic_person(sender, instance, created, **kwargs):
    if created:
        ocd_part = instance.id.rsplit("-", 1)[-1]
        slug = "{0}-{1}".format(slugify(instance.name), ocd_part)

        cp = CouncilmaticPerson(person=instance, slug=slug)
        # just update the child table, not the parent table
        cp.save_base(raw=True)


@receiver(post_save, sender=OCDEvent)
def create_councilmatic_event(sender, instance, created, **kwargs):
    if created:
        truncator = Truncator(instance.name)
        ocd_part = instance.id.rsplit("-", 1)[-1]
        slug = "{0}-{1}".format(slugify(truncator.words(5)), ocd_part)

        ce = CouncilmaticEvent(event=instance, slug=slug)

        # just update the child table, not the parent table
        ce.save_base(raw=True)

    for entity in OCDEventRelatedEntity.objects.filter(
        agenda_item__event=instance, bill__isnull=False
    ):
        cb = entity.bill.councilmatic_bill
        cb.last_action_date = cb.get_last_action_date()
        cb.save_base(raw=True)


@receiver(post_save, sender=OCDBill)
def create_councilmatic_bill(sender, instance, created, **kwargs):
    if created:
        slug = slugify(instance.identifier)

        cb = CouncilmaticBill(bill=instance, slug=slug)

    else:
        cb = instance.councilmatic_bill

    cb.last_action_date = cb.get_last_action_date()

    # just update the child table, not the parent table
    cb.save_base(raw=True)


@receiver(post_save, sender=OCDPost)
def create_councilmatic_post(sender, instance, created, **kwargs):
    if created:
        cp = CouncilmaticPost(post=instance)
        cp.save_base(raw=True)



import os
import subprocess
import logging
import logging.config
import signal

from django.core.management.base import BaseCommand
from django.conf import settings
from django.db.models import Max, Q

from councilmatic_core.models import Bill

logging.config.dictConfig(settings.LOGGING)
logging.getLogger("requests").setLevel(logging.WARNING)
logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = "Converts RTF-formatted legislative text to valid HTML"

    def add_arguments(self, parser):
        parser.add_argument(
            "--update_all",
            default=False,
            action="store_true",
            help="Update html_text in all bills.",
        )

        parser.add_argument(
            "--update_empty",
            default=False,
            action="store_true",
            help="Update bills that currently do not have html_text.",
        )

    def handle(self, *args, **options):
        self.update_all = options["update_all"]
        self.update_empty = options["update_empty"]

        listener = subprocess.Popen(
            ["unoconv", "--listener"],
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL,
        )

        try:
            self.add_html()
        finally:
            listener.terminate()

    def get_rtf(self):
        max_updated = Bill.objects.all().aggregate(Max("updated_at"))["updated_at__max"]

        has_rtf_text = Q(extras__rtf_text__isnull=False)
        missing_html_text = Q(extras__html_text__isnull=True)
        after_max_update = Q(updated_at__gt=max_updated)

        if max_updated is None or self.update_all:
            qs = Bill.objects.filter(has_rtf_text)
        elif self.update_empty:
            qs = Bill.objects.filter(has_rtf_text & missing_html_text)
        else:
            qs = Bill.objects.filter(has_rtf_text & after_max_update)

        yield from qs.iterator()

    def get_html(self):
        logger.info("Converting RTF to HTML....")

        for bill in self.get_rtf():
            ocd_id = bill.id
            rtf_string = bill.extras["rtf_text"]

            process = subprocess.Popen(
                ["unoconv", "--stdin", "--stdout", "-f", "html"],
                preexec_fn=os.setsid,
                stdin=subprocess.PIPE,
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE,
            )

            try:
                stdout_data, _ = process.communicate(
                    input=rtf_string.encode(), timeout=30
                )

            except subprocess.TimeoutExpired as e:
                os.killpg(os.getpgid(process.pid), signal.SIGTERM)

                logger.error(e)
                logger.error("Look at bill {}".format(ocd_id))
                continue

            else:
                html = stdout_data.decode("utf-8")

            try:
                assert html

            except AssertionError:
                logger.error(f"Converted HTML for bill {ocd_id} is empty")
                continue

            logger.info("Successful conversion of {}".format(ocd_id))

            bill.extras["html_text"] = html

            yield bill

    def add_html(self):
        Bill.objects.bulk_update(self.get_html(), ["extras"], batch_size=100)

        logger.info("Bills have valid, viewable HTML!")



# Generated by Django 2.1.8 on 2019-05-13 17:50

import django.core.files.storage
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("legislative", "0008_longer_event_name"),
        ("core", "0004_auto_20171005_2028"),
        ("councilmatic_core", "0044_bill_restrict_view"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="action",
            name="_bill",
        ),
        migrations.RemoveField(
            model_name="action",
            name="_organization",
        ),
        migrations.RemoveField(
            model_name="actionrelatedentity",
            name="_action",
        ),
        migrations.RemoveField(
            model_name="billdocument",
            name="bill",
        ),
        migrations.RemoveField(
            model_name="eventagendaitem",
            name="bill",
        ),
        migrations.RemoveField(
            model_name="eventagendaitem",
            name="event",
        ),
        migrations.RemoveField(
            model_name="eventdocument",
            name="event",
        ),
        migrations.RemoveField(
            model_name="eventmedia",
            name="event",
        ),
        migrations.RemoveField(
            model_name="eventparticipant",
            name="event",
        ),
        migrations.RemoveField(
            model_name="membership",
            name="_organization",
        ),
        migrations.RemoveField(
            model_name="membership",
            name="_person",
        ),
        migrations.RemoveField(
            model_name="membership",
            name="_post",
        ),
        migrations.RemoveField(
            model_name="post",
            name="_organization",
        ),
        migrations.RemoveField(
            model_name="relatedbill",
            name="central_bill",
        ),
        migrations.RemoveField(
            model_name="sponsorship",
            name="_bill",
        ),
        migrations.RemoveField(
            model_name="sponsorship",
            name="_person",
        ),
        migrations.RemoveField(
            model_name="subject",
            name="bill",
        ),
        migrations.CreateModel(
            name="BillAction",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
            },
            bases=("legislative.billaction",),
        ),
        migrations.CreateModel(
            name="BillActionRelatedEntity",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
            },
            bases=("legislative.billactionrelatedentity",),
        ),
        migrations.CreateModel(
            name="BillSponsorship",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
            },
            bases=("legislative.billsponsorship",),
        ),
        migrations.RemoveField(
            model_name="bill",
            name="_from_organization",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="_legislative_session",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="abstract",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="bill_type",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="classification",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="description",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="full_text",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="html_text",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="identifier",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="last_action_date",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="ocd_created_at",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="ocd_id",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="ocd_updated_at",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="ocr_full_text",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="source_note",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="source_url",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="updated_at",
        ),
        migrations.RemoveField(
            model_name="event",
            name="all_day",
        ),
        migrations.RemoveField(
            model_name="event",
            name="classification",
        ),
        migrations.RemoveField(
            model_name="event",
            name="description",
        ),
        migrations.RemoveField(
            model_name="event",
            name="end_time",
        ),
        migrations.RemoveField(
            model_name="event",
            name="extras",
        ),
        migrations.RemoveField(
            model_name="event",
            name="location_name",
        ),
        migrations.RemoveField(
            model_name="event",
            name="location_url",
        ),
        migrations.RemoveField(
            model_name="event",
            name="name",
        ),
        migrations.RemoveField(
            model_name="event",
            name="ocd_created_at",
        ),
        migrations.RemoveField(
            model_name="event",
            name="ocd_id",
        ),
        migrations.RemoveField(
            model_name="event",
            name="ocd_updated_at",
        ),
        migrations.RemoveField(
            model_name="event",
            name="source_note",
        ),
        migrations.RemoveField(
            model_name="event",
            name="source_url",
        ),
        migrations.RemoveField(
            model_name="event",
            name="start_time",
        ),
        migrations.RemoveField(
            model_name="event",
            name="status",
        ),
        migrations.RemoveField(
            model_name="event",
            name="updated_at",
        ),
        migrations.RemoveField(
            model_name="organization",
            name="_parent",
        ),
        migrations.RemoveField(
            model_name="organization",
            name="classification",
        ),
        migrations.RemoveField(
            model_name="organization",
            name="jurisdiction",
        ),
        migrations.RemoveField(
            model_name="organization",
            name="name",
        ),
        migrations.RemoveField(
            model_name="organization",
            name="ocd_id",
        ),
        migrations.RemoveField(
            model_name="organization",
            name="source_url",
        ),
        migrations.RemoveField(
            model_name="organization",
            name="updated_at",
        ),
        migrations.RemoveField(
            model_name="person",
            name="email",
        ),
        migrations.RemoveField(
            model_name="person",
            name="name",
        ),
        migrations.RemoveField(
            model_name="person",
            name="ocd_id",
        ),
        migrations.RemoveField(
            model_name="person",
            name="source_note",
        ),
        migrations.RemoveField(
            model_name="person",
            name="source_url",
        ),
        migrations.RemoveField(
            model_name="person",
            name="updated_at",
        ),
        migrations.RemoveField(
            model_name="person",
            name="website_url",
        ),
        migrations.AddField(
            model_name="bill",
            name="bill",
            field=models.OneToOneField(
                default="foo",
                on_delete=django.db.models.deletion.CASCADE,
                parent_link=True,
                primary_key=True,
                related_name="councilmatic_bill",
                serialize=False,
                to="legislative.Bill",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="event",
            name="event",
            field=models.OneToOneField(
                default="foo",
                on_delete=django.db.models.deletion.CASCADE,
                parent_link=True,
                primary_key=True,
                related_name="councilmatic_event",
                serialize=False,
                to="legislative.Event",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="organization",
            name="organization",
            field=models.OneToOneField(
                default="foo",
                on_delete=django.db.models.deletion.CASCADE,
                parent_link=True,
                primary_key=True,
                related_name="councilmatic_organization",
                serialize=False,
                to="core.Organization",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="person",
            name="person",
            field=models.OneToOneField(
                default="foo",
                on_delete=django.db.models.deletion.CASCADE,
                parent_link=True,
                primary_key=True,
                related_name="councilmatic_person",
                serialize=False,
                to="core.Person",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="bill",
            name="slug",
            field=models.SlugField(),
        ),
        migrations.AlterField(
            model_name="event",
            name="slug",
            field=models.SlugField(max_length=200),
        ),
        migrations.AlterField(
            model_name="organization",
            name="slug",
            field=models.SlugField(max_length=200),
        ),
        migrations.AlterField(
            model_name="person",
            name="headshot",
            field=models.FileField(
                default="images/headshot_placeholder.png",
                storage=django.core.files.storage.FileSystemStorage(
                    base_url="/", location="/Users/fgregg/work/chi-councilmatic/static"
                ),
                upload_to="images",
            ),
        ),
        migrations.AlterField(
            model_name="person",
            name="slug",
            field=models.SlugField(),
        ),
        migrations.DeleteModel(
            name="Action",
        ),
        migrations.DeleteModel(
            name="ActionRelatedEntity",
        ),
        migrations.DeleteModel(
            name="BillDocument",
        ),
        migrations.DeleteModel(
            name="EventAgendaItem",
        ),
        migrations.DeleteModel(
            name="EventDocument",
        ),
        migrations.DeleteModel(
            name="EventMedia",
        ),
        migrations.DeleteModel(
            name="EventParticipant",
        ),
        migrations.DeleteModel(
            name="Jurisdiction",
        ),
        migrations.DeleteModel(
            name="LegislativeSession",
        ),
        migrations.DeleteModel(
            name="Membership",
        ),
        migrations.DeleteModel(
            name="Post",
        ),
        migrations.DeleteModel(
            name="RelatedBill",
        ),
        migrations.DeleteModel(
            name="Sponsorship",
        ),
        migrations.DeleteModel(
            name="Subject",
        ),
        migrations.CreateModel(
            name="Membership",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
            },
            bases=("core.membership",),
        ),
        migrations.CreateModel(
            name="Post",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
            },
            bases=("core.post",),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-10-14 18:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0020_auto_20161013_1704"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="billdocument",
            name="document",
        ),
        migrations.RemoveField(
            model_name="eventdocument",
            name="document",
        ),
        migrations.RemoveField(
            model_name="eventdocument",
            name="updated_at",
        ),
        migrations.AddField(
            model_name="billdocument",
            name="full_text",
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name="billdocument",
            name="note",
            field=models.TextField(default=""),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="billdocument",
            name="url",
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name="eventdocument",
            name="full_text",
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name="eventdocument",
            name="note",
            field=models.TextField(default=""),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="eventdocument",
            name="url",
            field=models.TextField(blank=True),
        ),
        migrations.DeleteModel(
            name="Document",
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-04-12 15:53
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0038_auto_20180403_1003"),
    ]

    operations = [
        migrations.CreateModel(
            name="EventMedia",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("url", models.CharField(max_length=555)),
            ],
        ),
        migrations.AddField(
            model_name="eventmedia",
            name="event",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="media_urls",
                to="councilmatic_core.Event",
            ),
        ),
        migrations.RunSQL(
            """
            INSERT INTO councilmatic_core_eventmedia (event_id, url)
              SELECT
                ocd_id,
                media_url
              FROM councilmatic_core_event AS event
              WHERE media_url IS NOT NULL
        """
        ),
        migrations.RemoveField(
            model_name="event",
            name="media_url",
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-03-26 20:31
from __future__ import unicode_literals
import re

from django.conf import settings
from django.db import migrations, models
from django.utils.text import slugify


class Migration(migrations.Migration):
    def unmangle_identifier(apps, schema_editor):
        """
        The `fix_bill_id` function mangled bill identifiers in at least two ways:
        (1) removing zeroes, e.g., 'Res 0229-2004' (original) becomes 'Res 229-2004' (mangled)
        (2) adding a space, e.g., 'T2018-1245' (original) becomes 'T 2018-1245' (mangled).

        For NYC, the second case ONLY affected bills that begin with 'T', and the first case did NOT affect bills that begin with 'T' - that is, NYC bills never follow these patterns 'T 0023-2015' or 'T0023-2015'.

        This migration unmangles identifiers and changes the slugs accordingly.
        """

        Bill = apps.get_model("councilmatic_core", "Bill")

        # New York City
        if settings.OCD_CITY_COUNCIL_NAME == "New York City Council":
            deleted_zeroes = r"^((?!T\s)[A-Za-z]+)\s(\d{1,3})-([-\w]+)$"
            for bill in Bill.objects.filter(identifier__iregex=deleted_zeroes):
                match = re.match(deleted_zeroes, bill.identifier)
                unmangled_identifier = (
                    "{prefix} {mangled_count:0>4}-{remainder}".format(
                        prefix=match.group(1),
                        mangled_count=match.group(2),
                        remainder=match.group(3),
                    )
                )

                print("{} becomes {}".format(bill.identifier, unmangled_identifier))
                try:
                    duplicate = Bill.objects.get(identifier=unmangled_identifier)
                    print(
                        "{} - duplicate found. Deleting.".format(unmangled_identifier)
                    )
                    duplicate.delete()
                except Bill.DoesNotExist:
                    pass

                bill.identifier = unmangled_identifier
                bill.slug = slugify(unmangled_identifier)
                bill.save()

            added_space = r"^(T)\s([-\d]+)$"
            for bill in Bill.objects.filter(identifier__iregex=added_space):
                match = re.match(added_space, bill.identifier)
                unmangled_identifier = "{mangled_prefix}{count}".format(
                    mangled_prefix=match.group(1), count=match.group(2)
                )

                print("{} becomes {}".format(bill.identifier, unmangled_identifier))
                try:
                    duplicate = Bill.objects.get(identifier=unmangled_identifier)
                    print(
                        "{} - duplicate found. Deleting.".format(unmangled_identifier)
                    )
                    duplicate.delete()
                except Bill.DoesNotExist:
                    pass

                bill.identifier = unmangled_identifier
                bill.slug = slugify(unmangled_identifier)
                bill.save()

    dependencies = [
        ("councilmatic_core", "0036_auto_20180302_1247"),
    ]

    operations = [migrations.RunPython(unmangle_identifier)]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2019-02-07 14:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0043_membership_extras"),
    ]

    operations = [
        migrations.AddField(
            model_name="bill",
            name="restrict_view",
            field=models.BooleanField(default=False),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0005_auto_20151215_1430"),
    ]

    operations = [
        migrations.AddField(
            model_name="bill",
            name="subject",
            field=models.CharField(blank=True, max_length=255),
        ),
    ]
